@@ -1,7 +1,6 @@
 from jinja2 import Environment, PackageLoader, StrictUndefined
 
 from strictdoc.export.html.document_type import DocumentType
-from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 
 
 class DocumentTableHTMLGenerator:
@@ -12,18 +11,11 @@ class DocumentTableHTMLGenerator:
     env.globals.update(isinstance=isinstance)
 
     @staticmethod
-    def export(config, document, traceability_index, link_renderer):
+    def export(
+        config, document, traceability_index, markup_renderer, link_renderer
+    ):
         output = ""
 
-        document_type = DocumentType.table()
-        markup_renderer = MarkupRenderer.create(
-            document.config.markup,
-            traceability_index,
-            link_renderer,
-            document,
-            document_type,
-        )
-
         template = DocumentTableHTMLGenerator.env.get_template(
             "single_document_table/document.jinja.html"
         )
@@ -38,7 +30,7 @@ class DocumentTableHTMLGenerator:
             traceability_index=traceability_index,
             renderer=markup_renderer,
             link_renderer=link_renderer,
-            document_type=document_type,
+            document_type=DocumentType.table(),
             standalone=False,
             root_path=root_path,
             static_path=static_path,
